from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class RadiationEquivalentDoseUnits(Enum):
        """
            RadiationEquivalentDoseUnits enumeration
        """
        
        Sievert = 'sievert'
        """
            The sievert is a unit in the International System of Units (SI) intended to represent the stochastic health risk of ionizing radiation, which is defined as the probability of causing radiation-induced cancer and genetic damage.
        """
        
        RoentgenEquivalentMan = 'roentgen_equivalent_man'
        """
            
        """
        
        Nanosievert = 'nanosievert'
        """
            
        """
        
        Microsievert = 'microsievert'
        """
            
        """
        
        Millisievert = 'millisievert'
        """
            
        """
        
        MilliroentgenEquivalentMan = 'milliroentgen_equivalent_man'
        """
            
        """
        

class RadiationEquivalentDose(AbstractMeasure):
    """
    Equivalent dose is a dose quantity representing the stochastic health effects of low levels of ionizing radiation on the human body which represents the probability of radiation-induced cancer and genetic damage.

    Args:
        value (float): The value.
        from_unit (RadiationEquivalentDoseUnits): The RadiationEquivalentDose unit to create from, The default unit is Sievert
    """
    def __init__(self, value: float, from_unit: RadiationEquivalentDoseUnits = RadiationEquivalentDoseUnits.Sievert):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__sieverts = None
        
        self.__roentgens_equivalent_man = None
        
        self.__nanosieverts = None
        
        self.__microsieverts = None
        
        self.__millisieverts = None
        
        self.__milliroentgens_equivalent_man = None
        

    def convert(self, unit: RadiationEquivalentDoseUnits) -> float:
        return self.__convert_from_base(unit)

    def __convert_from_base(self, from_unit: RadiationEquivalentDoseUnits) -> float:
        value = self._value
        
        if from_unit == RadiationEquivalentDoseUnits.Sievert:
            return (value)
        
        if from_unit == RadiationEquivalentDoseUnits.RoentgenEquivalentMan:
            return (value * 100)
        
        if from_unit == RadiationEquivalentDoseUnits.Nanosievert:
            return ((value) / 1e-09)
        
        if from_unit == RadiationEquivalentDoseUnits.Microsievert:
            return ((value) / 1e-06)
        
        if from_unit == RadiationEquivalentDoseUnits.Millisievert:
            return ((value) / 0.001)
        
        if from_unit == RadiationEquivalentDoseUnits.MilliroentgenEquivalentMan:
            return ((value * 100) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: RadiationEquivalentDoseUnits) -> float:
        
        if to_unit == RadiationEquivalentDoseUnits.Sievert:
            return (value)
        
        if to_unit == RadiationEquivalentDoseUnits.RoentgenEquivalentMan:
            return (value / 100)
        
        if to_unit == RadiationEquivalentDoseUnits.Nanosievert:
            return ((value) * 1e-09)
        
        if to_unit == RadiationEquivalentDoseUnits.Microsievert:
            return ((value) * 1e-06)
        
        if to_unit == RadiationEquivalentDoseUnits.Millisievert:
            return ((value) * 0.001)
        
        if to_unit == RadiationEquivalentDoseUnits.MilliroentgenEquivalentMan:
            return ((value / 100) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_sieverts(sieverts: float):
        """
        Create a new instance of RadiationEquivalentDose from a value in sieverts.

        The sievert is a unit in the International System of Units (SI) intended to represent the stochastic health risk of ionizing radiation, which is defined as the probability of causing radiation-induced cancer and genetic damage.

        :param meters: The RadiationEquivalentDose value in sieverts.
        :type sieverts: float
        :return: A new instance of RadiationEquivalentDose.
        :rtype: RadiationEquivalentDose
        """
        return RadiationEquivalentDose(sieverts, RadiationEquivalentDoseUnits.Sievert)

    
    @staticmethod
    def from_roentgens_equivalent_man(roentgens_equivalent_man: float):
        """
        Create a new instance of RadiationEquivalentDose from a value in roentgens_equivalent_man.

        

        :param meters: The RadiationEquivalentDose value in roentgens_equivalent_man.
        :type roentgens_equivalent_man: float
        :return: A new instance of RadiationEquivalentDose.
        :rtype: RadiationEquivalentDose
        """
        return RadiationEquivalentDose(roentgens_equivalent_man, RadiationEquivalentDoseUnits.RoentgenEquivalentMan)

    
    @staticmethod
    def from_nanosieverts(nanosieverts: float):
        """
        Create a new instance of RadiationEquivalentDose from a value in nanosieverts.

        

        :param meters: The RadiationEquivalentDose value in nanosieverts.
        :type nanosieverts: float
        :return: A new instance of RadiationEquivalentDose.
        :rtype: RadiationEquivalentDose
        """
        return RadiationEquivalentDose(nanosieverts, RadiationEquivalentDoseUnits.Nanosievert)

    
    @staticmethod
    def from_microsieverts(microsieverts: float):
        """
        Create a new instance of RadiationEquivalentDose from a value in microsieverts.

        

        :param meters: The RadiationEquivalentDose value in microsieverts.
        :type microsieverts: float
        :return: A new instance of RadiationEquivalentDose.
        :rtype: RadiationEquivalentDose
        """
        return RadiationEquivalentDose(microsieverts, RadiationEquivalentDoseUnits.Microsievert)

    
    @staticmethod
    def from_millisieverts(millisieverts: float):
        """
        Create a new instance of RadiationEquivalentDose from a value in millisieverts.

        

        :param meters: The RadiationEquivalentDose value in millisieverts.
        :type millisieverts: float
        :return: A new instance of RadiationEquivalentDose.
        :rtype: RadiationEquivalentDose
        """
        return RadiationEquivalentDose(millisieverts, RadiationEquivalentDoseUnits.Millisievert)

    
    @staticmethod
    def from_milliroentgens_equivalent_man(milliroentgens_equivalent_man: float):
        """
        Create a new instance of RadiationEquivalentDose from a value in milliroentgens_equivalent_man.

        

        :param meters: The RadiationEquivalentDose value in milliroentgens_equivalent_man.
        :type milliroentgens_equivalent_man: float
        :return: A new instance of RadiationEquivalentDose.
        :rtype: RadiationEquivalentDose
        """
        return RadiationEquivalentDose(milliroentgens_equivalent_man, RadiationEquivalentDoseUnits.MilliroentgenEquivalentMan)

    
    @property
    def sieverts(self) -> float:
        """
        The sievert is a unit in the International System of Units (SI) intended to represent the stochastic health risk of ionizing radiation, which is defined as the probability of causing radiation-induced cancer and genetic damage.
        """
        if self.__sieverts != None:
            return self.__sieverts
        self.__sieverts = self.__convert_from_base(RadiationEquivalentDoseUnits.Sievert)
        return self.__sieverts

    
    @property
    def roentgens_equivalent_man(self) -> float:
        """
        
        """
        if self.__roentgens_equivalent_man != None:
            return self.__roentgens_equivalent_man
        self.__roentgens_equivalent_man = self.__convert_from_base(RadiationEquivalentDoseUnits.RoentgenEquivalentMan)
        return self.__roentgens_equivalent_man

    
    @property
    def nanosieverts(self) -> float:
        """
        
        """
        if self.__nanosieverts != None:
            return self.__nanosieverts
        self.__nanosieverts = self.__convert_from_base(RadiationEquivalentDoseUnits.Nanosievert)
        return self.__nanosieverts

    
    @property
    def microsieverts(self) -> float:
        """
        
        """
        if self.__microsieverts != None:
            return self.__microsieverts
        self.__microsieverts = self.__convert_from_base(RadiationEquivalentDoseUnits.Microsievert)
        return self.__microsieverts

    
    @property
    def millisieverts(self) -> float:
        """
        
        """
        if self.__millisieverts != None:
            return self.__millisieverts
        self.__millisieverts = self.__convert_from_base(RadiationEquivalentDoseUnits.Millisievert)
        return self.__millisieverts

    
    @property
    def milliroentgens_equivalent_man(self) -> float:
        """
        
        """
        if self.__milliroentgens_equivalent_man != None:
            return self.__milliroentgens_equivalent_man
        self.__milliroentgens_equivalent_man = self.__convert_from_base(RadiationEquivalentDoseUnits.MilliroentgenEquivalentMan)
        return self.__milliroentgens_equivalent_man

    
    def to_string(self, unit: RadiationEquivalentDoseUnits = RadiationEquivalentDoseUnits.Sievert) -> str:
        """
        Format the RadiationEquivalentDose to string.
        Note! the default format for RadiationEquivalentDose is Sievert.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == RadiationEquivalentDoseUnits.Sievert:
            return f"""{self.sieverts} Sv"""
        
        if unit == RadiationEquivalentDoseUnits.RoentgenEquivalentMan:
            return f"""{self.roentgens_equivalent_man} rem"""
        
        if unit == RadiationEquivalentDoseUnits.Nanosievert:
            return f"""{self.nanosieverts} nSv"""
        
        if unit == RadiationEquivalentDoseUnits.Microsievert:
            return f"""{self.microsieverts} μSv"""
        
        if unit == RadiationEquivalentDoseUnits.Millisievert:
            return f"""{self.millisieverts} mSv"""
        
        if unit == RadiationEquivalentDoseUnits.MilliroentgenEquivalentMan:
            return f"""{self.milliroentgens_equivalent_man} mrem"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: RadiationEquivalentDoseUnits = RadiationEquivalentDoseUnits.Sievert) -> str:
        """
        Get RadiationEquivalentDose unit abbreviation.
        Note! the default abbreviation for RadiationEquivalentDose is Sievert.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == RadiationEquivalentDoseUnits.Sievert:
            return """Sv"""
        
        if unit_abbreviation == RadiationEquivalentDoseUnits.RoentgenEquivalentMan:
            return """rem"""
        
        if unit_abbreviation == RadiationEquivalentDoseUnits.Nanosievert:
            return """nSv"""
        
        if unit_abbreviation == RadiationEquivalentDoseUnits.Microsievert:
            return """μSv"""
        
        if unit_abbreviation == RadiationEquivalentDoseUnits.Millisievert:
            return """mSv"""
        
        if unit_abbreviation == RadiationEquivalentDoseUnits.MilliroentgenEquivalentMan:
            return """mrem"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class MolalityUnits(Enum):
        """
            MolalityUnits enumeration
        """
        
        MolePerKilogram = 'mole_per_kilogram'
        """
            
        """
        
        MolePerGram = 'mole_per_gram'
        """
            
        """
        

class Molality(AbstractMeasure):
    """
    Molality is a measure of the amount of solute in a solution relative to a given mass of solvent.

    Args:
        value (float): The value.
        from_unit (MolalityUnits): The Molality unit to create from, The default unit is MolePerKilogram
    """
    def __init__(self, value: float, from_unit: MolalityUnits = MolalityUnits.MolePerKilogram):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__moles_per_kilogram = None
        
        self.__moles_per_gram = None
        

    def convert(self, unit: MolalityUnits) -> float:
        return self.__convert_from_base(unit)

    def __convert_from_base(self, from_unit: MolalityUnits) -> float:
        value = self._value
        
        if from_unit == MolalityUnits.MolePerKilogram:
            return (value)
        
        if from_unit == MolalityUnits.MolePerGram:
            return (value * 1e-3)
        
        return None


    def __convert_to_base(self, value: float, to_unit: MolalityUnits) -> float:
        
        if to_unit == MolalityUnits.MolePerKilogram:
            return (value)
        
        if to_unit == MolalityUnits.MolePerGram:
            return (value / 1e-3)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_moles_per_kilogram(moles_per_kilogram: float):
        """
        Create a new instance of Molality from a value in moles_per_kilogram.

        

        :param meters: The Molality value in moles_per_kilogram.
        :type moles_per_kilogram: float
        :return: A new instance of Molality.
        :rtype: Molality
        """
        return Molality(moles_per_kilogram, MolalityUnits.MolePerKilogram)

    
    @staticmethod
    def from_moles_per_gram(moles_per_gram: float):
        """
        Create a new instance of Molality from a value in moles_per_gram.

        

        :param meters: The Molality value in moles_per_gram.
        :type moles_per_gram: float
        :return: A new instance of Molality.
        :rtype: Molality
        """
        return Molality(moles_per_gram, MolalityUnits.MolePerGram)

    
    @property
    def moles_per_kilogram(self) -> float:
        """
        
        """
        if self.__moles_per_kilogram != None:
            return self.__moles_per_kilogram
        self.__moles_per_kilogram = self.__convert_from_base(MolalityUnits.MolePerKilogram)
        return self.__moles_per_kilogram

    
    @property
    def moles_per_gram(self) -> float:
        """
        
        """
        if self.__moles_per_gram != None:
            return self.__moles_per_gram
        self.__moles_per_gram = self.__convert_from_base(MolalityUnits.MolePerGram)
        return self.__moles_per_gram

    
    def to_string(self, unit: MolalityUnits = MolalityUnits.MolePerKilogram) -> str:
        """
        Format the Molality to string.
        Note! the default format for Molality is MolePerKilogram.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == MolalityUnits.MolePerKilogram:
            return f"""{self.moles_per_kilogram} mol/kg"""
        
        if unit == MolalityUnits.MolePerGram:
            return f"""{self.moles_per_gram} mol/g"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: MolalityUnits = MolalityUnits.MolePerKilogram) -> str:
        """
        Get Molality unit abbreviation.
        Note! the default abbreviation for Molality is MolePerKilogram.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == MolalityUnits.MolePerKilogram:
            return """mol/kg"""
        
        if unit_abbreviation == MolalityUnits.MolePerGram:
            return """mol/g"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class LuminousFluxUnits(Enum):
        """
            LuminousFluxUnits enumeration
        """
        
        Lumen = 'lumen'
        """
            
        """
        

class LuminousFlux(AbstractMeasure):
    """
    In photometry, luminous flux or luminous power is the measure of the perceived power of light.

    Args:
        value (float): The value.
        from_unit (LuminousFluxUnits): The LuminousFlux unit to create from, The default unit is Lumen
    """
    def __init__(self, value: float, from_unit: LuminousFluxUnits = LuminousFluxUnits.Lumen):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__lumens = None
        

    def convert(self, unit: LuminousFluxUnits) -> float:
        return self.__convert_from_base(unit)

    def __convert_from_base(self, from_unit: LuminousFluxUnits) -> float:
        value = self._value
        
        if from_unit == LuminousFluxUnits.Lumen:
            return (value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LuminousFluxUnits) -> float:
        
        if to_unit == LuminousFluxUnits.Lumen:
            return (value)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_lumens(lumens: float):
        """
        Create a new instance of LuminousFlux from a value in lumens.

        

        :param meters: The LuminousFlux value in lumens.
        :type lumens: float
        :return: A new instance of LuminousFlux.
        :rtype: LuminousFlux
        """
        return LuminousFlux(lumens, LuminousFluxUnits.Lumen)

    
    @property
    def lumens(self) -> float:
        """
        
        """
        if self.__lumens != None:
            return self.__lumens
        self.__lumens = self.__convert_from_base(LuminousFluxUnits.Lumen)
        return self.__lumens

    
    def to_string(self, unit: LuminousFluxUnits = LuminousFluxUnits.Lumen) -> str:
        """
        Format the LuminousFlux to string.
        Note! the default format for LuminousFlux is Lumen.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LuminousFluxUnits.Lumen:
            return f"""{self.lumens} lm"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: LuminousFluxUnits = LuminousFluxUnits.Lumen) -> str:
        """
        Get LuminousFlux unit abbreviation.
        Note! the default abbreviation for LuminousFlux is Lumen.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LuminousFluxUnits.Lumen:
            return """lm"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class RadiationExposureUnits(Enum):
        """
            RadiationExposureUnits enumeration
        """
        
        CoulombPerKilogram = 'coulomb_per_kilogram'
        """
            
        """
        
        Roentgen = 'roentgen'
        """
            
        """
        
        PicocoulombPerKilogram = 'picocoulomb_per_kilogram'
        """
            
        """
        
        NanocoulombPerKilogram = 'nanocoulomb_per_kilogram'
        """
            
        """
        
        MicrocoulombPerKilogram = 'microcoulomb_per_kilogram'
        """
            
        """
        
        MillicoulombPerKilogram = 'millicoulomb_per_kilogram'
        """
            
        """
        
        Microroentgen = 'microroentgen'
        """
            
        """
        
        Milliroentgen = 'milliroentgen'
        """
            
        """
        

class RadiationExposure(AbstractMeasure):
    """
    Radiation exposure is a measure of the ionization of air due to ionizing radiation from photons.

    Args:
        value (float): The value.
        from_unit (RadiationExposureUnits): The RadiationExposure unit to create from, The default unit is CoulombPerKilogram
    """
    def __init__(self, value: float, from_unit: RadiationExposureUnits = RadiationExposureUnits.CoulombPerKilogram):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__coulombs_per_kilogram = None
        
        self.__roentgens = None
        
        self.__picocoulombs_per_kilogram = None
        
        self.__nanocoulombs_per_kilogram = None
        
        self.__microcoulombs_per_kilogram = None
        
        self.__millicoulombs_per_kilogram = None
        
        self.__microroentgens = None
        
        self.__milliroentgens = None
        

    def convert(self, unit: RadiationExposureUnits) -> float:
        return self.__convert_from_base(unit)

    def __convert_from_base(self, from_unit: RadiationExposureUnits) -> float:
        value = self._value
        
        if from_unit == RadiationExposureUnits.CoulombPerKilogram:
            return (value)
        
        if from_unit == RadiationExposureUnits.Roentgen:
            return (value / 2.58e-4)
        
        if from_unit == RadiationExposureUnits.PicocoulombPerKilogram:
            return ((value) / 1e-12)
        
        if from_unit == RadiationExposureUnits.NanocoulombPerKilogram:
            return ((value) / 1e-09)
        
        if from_unit == RadiationExposureUnits.MicrocoulombPerKilogram:
            return ((value) / 1e-06)
        
        if from_unit == RadiationExposureUnits.MillicoulombPerKilogram:
            return ((value) / 0.001)
        
        if from_unit == RadiationExposureUnits.Microroentgen:
            return ((value / 2.58e-4) / 1e-06)
        
        if from_unit == RadiationExposureUnits.Milliroentgen:
            return ((value / 2.58e-4) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: RadiationExposureUnits) -> float:
        
        if to_unit == RadiationExposureUnits.CoulombPerKilogram:
            return (value)
        
        if to_unit == RadiationExposureUnits.Roentgen:
            return (value * 2.58e-4)
        
        if to_unit == RadiationExposureUnits.PicocoulombPerKilogram:
            return ((value) * 1e-12)
        
        if to_unit == RadiationExposureUnits.NanocoulombPerKilogram:
            return ((value) * 1e-09)
        
        if to_unit == RadiationExposureUnits.MicrocoulombPerKilogram:
            return ((value) * 1e-06)
        
        if to_unit == RadiationExposureUnits.MillicoulombPerKilogram:
            return ((value) * 0.001)
        
        if to_unit == RadiationExposureUnits.Microroentgen:
            return ((value * 2.58e-4) * 1e-06)
        
        if to_unit == RadiationExposureUnits.Milliroentgen:
            return ((value * 2.58e-4) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_coulombs_per_kilogram(coulombs_per_kilogram: float):
        """
        Create a new instance of RadiationExposure from a value in coulombs_per_kilogram.

        

        :param meters: The RadiationExposure value in coulombs_per_kilogram.
        :type coulombs_per_kilogram: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(coulombs_per_kilogram, RadiationExposureUnits.CoulombPerKilogram)

    
    @staticmethod
    def from_roentgens(roentgens: float):
        """
        Create a new instance of RadiationExposure from a value in roentgens.

        

        :param meters: The RadiationExposure value in roentgens.
        :type roentgens: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(roentgens, RadiationExposureUnits.Roentgen)

    
    @staticmethod
    def from_picocoulombs_per_kilogram(picocoulombs_per_kilogram: float):
        """
        Create a new instance of RadiationExposure from a value in picocoulombs_per_kilogram.

        

        :param meters: The RadiationExposure value in picocoulombs_per_kilogram.
        :type picocoulombs_per_kilogram: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(picocoulombs_per_kilogram, RadiationExposureUnits.PicocoulombPerKilogram)

    
    @staticmethod
    def from_nanocoulombs_per_kilogram(nanocoulombs_per_kilogram: float):
        """
        Create a new instance of RadiationExposure from a value in nanocoulombs_per_kilogram.

        

        :param meters: The RadiationExposure value in nanocoulombs_per_kilogram.
        :type nanocoulombs_per_kilogram: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(nanocoulombs_per_kilogram, RadiationExposureUnits.NanocoulombPerKilogram)

    
    @staticmethod
    def from_microcoulombs_per_kilogram(microcoulombs_per_kilogram: float):
        """
        Create a new instance of RadiationExposure from a value in microcoulombs_per_kilogram.

        

        :param meters: The RadiationExposure value in microcoulombs_per_kilogram.
        :type microcoulombs_per_kilogram: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(microcoulombs_per_kilogram, RadiationExposureUnits.MicrocoulombPerKilogram)

    
    @staticmethod
    def from_millicoulombs_per_kilogram(millicoulombs_per_kilogram: float):
        """
        Create a new instance of RadiationExposure from a value in millicoulombs_per_kilogram.

        

        :param meters: The RadiationExposure value in millicoulombs_per_kilogram.
        :type millicoulombs_per_kilogram: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(millicoulombs_per_kilogram, RadiationExposureUnits.MillicoulombPerKilogram)

    
    @staticmethod
    def from_microroentgens(microroentgens: float):
        """
        Create a new instance of RadiationExposure from a value in microroentgens.

        

        :param meters: The RadiationExposure value in microroentgens.
        :type microroentgens: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(microroentgens, RadiationExposureUnits.Microroentgen)

    
    @staticmethod
    def from_milliroentgens(milliroentgens: float):
        """
        Create a new instance of RadiationExposure from a value in milliroentgens.

        

        :param meters: The RadiationExposure value in milliroentgens.
        :type milliroentgens: float
        :return: A new instance of RadiationExposure.
        :rtype: RadiationExposure
        """
        return RadiationExposure(milliroentgens, RadiationExposureUnits.Milliroentgen)

    
    @property
    def coulombs_per_kilogram(self) -> float:
        """
        
        """
        if self.__coulombs_per_kilogram != None:
            return self.__coulombs_per_kilogram
        self.__coulombs_per_kilogram = self.__convert_from_base(RadiationExposureUnits.CoulombPerKilogram)
        return self.__coulombs_per_kilogram

    
    @property
    def roentgens(self) -> float:
        """
        
        """
        if self.__roentgens != None:
            return self.__roentgens
        self.__roentgens = self.__convert_from_base(RadiationExposureUnits.Roentgen)
        return self.__roentgens

    
    @property
    def picocoulombs_per_kilogram(self) -> float:
        """
        
        """
        if self.__picocoulombs_per_kilogram != None:
            return self.__picocoulombs_per_kilogram
        self.__picocoulombs_per_kilogram = self.__convert_from_base(RadiationExposureUnits.PicocoulombPerKilogram)
        return self.__picocoulombs_per_kilogram

    
    @property
    def nanocoulombs_per_kilogram(self) -> float:
        """
        
        """
        if self.__nanocoulombs_per_kilogram != None:
            return self.__nanocoulombs_per_kilogram
        self.__nanocoulombs_per_kilogram = self.__convert_from_base(RadiationExposureUnits.NanocoulombPerKilogram)
        return self.__nanocoulombs_per_kilogram

    
    @property
    def microcoulombs_per_kilogram(self) -> float:
        """
        
        """
        if self.__microcoulombs_per_kilogram != None:
            return self.__microcoulombs_per_kilogram
        self.__microcoulombs_per_kilogram = self.__convert_from_base(RadiationExposureUnits.MicrocoulombPerKilogram)
        return self.__microcoulombs_per_kilogram

    
    @property
    def millicoulombs_per_kilogram(self) -> float:
        """
        
        """
        if self.__millicoulombs_per_kilogram != None:
            return self.__millicoulombs_per_kilogram
        self.__millicoulombs_per_kilogram = self.__convert_from_base(RadiationExposureUnits.MillicoulombPerKilogram)
        return self.__millicoulombs_per_kilogram

    
    @property
    def microroentgens(self) -> float:
        """
        
        """
        if self.__microroentgens != None:
            return self.__microroentgens
        self.__microroentgens = self.__convert_from_base(RadiationExposureUnits.Microroentgen)
        return self.__microroentgens

    
    @property
    def milliroentgens(self) -> float:
        """
        
        """
        if self.__milliroentgens != None:
            return self.__milliroentgens
        self.__milliroentgens = self.__convert_from_base(RadiationExposureUnits.Milliroentgen)
        return self.__milliroentgens

    
    def to_string(self, unit: RadiationExposureUnits = RadiationExposureUnits.CoulombPerKilogram) -> str:
        """
        Format the RadiationExposure to string.
        Note! the default format for RadiationExposure is CoulombPerKilogram.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == RadiationExposureUnits.CoulombPerKilogram:
            return f"""{self.coulombs_per_kilogram} C/kg"""
        
        if unit == RadiationExposureUnits.Roentgen:
            return f"""{self.roentgens} R"""
        
        if unit == RadiationExposureUnits.PicocoulombPerKilogram:
            return f"""{self.picocoulombs_per_kilogram} pC/kg"""
        
        if unit == RadiationExposureUnits.NanocoulombPerKilogram:
            return f"""{self.nanocoulombs_per_kilogram} nC/kg"""
        
        if unit == RadiationExposureUnits.MicrocoulombPerKilogram:
            return f"""{self.microcoulombs_per_kilogram} μC/kg"""
        
        if unit == RadiationExposureUnits.MillicoulombPerKilogram:
            return f"""{self.millicoulombs_per_kilogram} mC/kg"""
        
        if unit == RadiationExposureUnits.Microroentgen:
            return f"""{self.microroentgens} μR"""
        
        if unit == RadiationExposureUnits.Milliroentgen:
            return f"""{self.milliroentgens} mR"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: RadiationExposureUnits = RadiationExposureUnits.CoulombPerKilogram) -> str:
        """
        Get RadiationExposure unit abbreviation.
        Note! the default abbreviation for RadiationExposure is CoulombPerKilogram.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == RadiationExposureUnits.CoulombPerKilogram:
            return """C/kg"""
        
        if unit_abbreviation == RadiationExposureUnits.Roentgen:
            return """R"""
        
        if unit_abbreviation == RadiationExposureUnits.PicocoulombPerKilogram:
            return """pC/kg"""
        
        if unit_abbreviation == RadiationExposureUnits.NanocoulombPerKilogram:
            return """nC/kg"""
        
        if unit_abbreviation == RadiationExposureUnits.MicrocoulombPerKilogram:
            return """μC/kg"""
        
        if unit_abbreviation == RadiationExposureUnits.MillicoulombPerKilogram:
            return """mC/kg"""
        
        if unit_abbreviation == RadiationExposureUnits.Microroentgen:
            return """μR"""
        
        if unit_abbreviation == RadiationExposureUnits.Milliroentgen:
            return """mR"""
        